#include <iostream>
#include <vector>
#include <string>
using namespace std;

void
svg_begin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end() {
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text) {
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void
svg_rect(double x, double y, double width, double height, string stroke, string fill){
    cout << "<rect x='" << x << "' y='" << y << "' width='" << width << "' height='" << height << "' stroke='" << stroke << "' fill='" << fill << "' />";
}



void
show_histogram_svg(const vector<double>& bins) {
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;
    const auto MAX_WIDTH = (IMAGE_WIDTH - TEXT_WIDTH);

    double sum = 0;
    double max_count = (bins[0] * BLOCK_WIDTH);
    for (double bin: bins){
        if ((bin * BLOCK_WIDTH) > max_count) {
            max_count = (bin * BLOCK_WIDTH);
        }
    }

    for (double bin: bins){
            sum = sum + (MAX_WIDTH * ((BLOCK_WIDTH * bin) / max_count));
    }

    double avg_width = sum/bins.size();


    svg_begin(400, 300);
    double top = 0;
    for (double bin : bins) {
        const double bin_width = MAX_WIDTH * ((BLOCK_WIDTH * bin) / max_count);
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        if (bin_width > avg_width){
            svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "black", "#e71320");
        }
        else {
            svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "black", "#2fe713");
        }
        top += BIN_HEIGHT;
    }
    svg_end();
}



